@@ -33,7 +33,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Author: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr. 1997
- * $Id: chasen.c,v 1.8 2001/02/24 06:17:22 kazuma-t Exp $
+ * $Id: chasen.c,v 1.17 2002/12/02 07:32:41 kazuma-t Exp $
  *
  */
 
@@ -54,24 +54,11 @@
 
 #include "chalib.h"
 
-#ifndef CHASEN_PORT
-#define CHASEN_PORT   31000  /* 󢪥㥻, äȶ줷(^^; */
-#endif
-
-#ifndef MAXHOSTNAMELEN
-#define MAXHOSTNAMELEN 64
-#endif
-
 static char *output_file = NULL;
-static char chasen_host[MAXHOSTNAMELEN];
-static unsigned short chasen_port = CHASEN_PORT;
 
 #define CHA_NAME       "ChaSen"
 #define CHA_PROG       "chasen"
 
-extern int chasen_client(char **, FILE *, char *, int);
-extern int chasen_server(char **, int);
-
 /*
  * opt_form_usage()
  */
@@ -171,15 +158,6 @@ usage(FILE * fp)
 {
     static char *message[] = {
 	"Usage: ", CHA_PROG, " [options] [file...]\n",
-	"  (how to run)\n",
-#ifndef NO_SERVER
-	"    -s             start ", CHA_NAME, " server\n",
-#endif
-	"    -P port        specify ", CHA_NAME, " server's port number\n",
-	"                   (use with -s, the default is 31000)\n",
-	"    -D host[:port] connect to ", CHA_NAME, " server\n",
-	"    -a             run standalone even if environment variable CHASENSERVER\n",
-	"                   is set\n",
 	"  (how to print ambiguous results)\n",
 	"    -b             show the best path (default)\n",
 	"    -m             show all morphemes\n",
@@ -189,7 +167,7 @@ usage(FILE * fp)
 	"    -e             show entire morpheme data\n",
 	"    -c             show coded morpheme data\n",
 	"    -d             show detailed morpheme data for Prolog\n",
-	"    -v             show detailed morpheme data for ViCha\n",
+	"    -v             show detailed morpheme data for VisualMorphs\n",
 	"    -F format      show morpheme with formatted output\n",
 	"    -Fh            print help of -F option\n",
 	"  (miscellaneous)\n",
@@ -219,39 +197,6 @@ usage(FILE * fp)
 	    fputs(*mes, fp);
 }
 
-/*
- * set_chasen_port()
- */
-static void
-set_chasen_port(char *port)
-{
-    if ((chasen_port = atoi(port)) <= 0)
-	cha_exit(1, "Illegal port No: %s", port);
-}
-
-/*
- * set_chasen_server()
- */
-static void
-set_chasen_server(char *server)
-{
-    char *colon;
-    int len;
-
-    if ((colon = strchr(server, ':')) == NULL) {
-	len = strlen(server);
-    } else {
-	set_chasen_port(colon + 1);
-	len = (int) (colon - server);
-    }
-
-    if (len >= MAXHOSTNAMELEN)
-	len = MAXHOSTNAMELEN - 1;
-
-    memcpy(chasen_host, server, len);
-    chasen_host[len] = '\0';
-}
-
 /*
  * getopt_argv()
  */
@@ -263,26 +208,12 @@ getopt_argv(char **argv)
     Cha_optind = 0;
     while ((c = cha_getopt_chasen(argv, stderr)) != EOF) {
 	switch (c) {
-	case 'a':		/* run standalone */
-	    chasen_host[0] = '\0';
-	    break;
-#ifndef NO_SERVER
-	case 's':		/* start server */
-	    Cha_server_mode = 1;
-	    break;
-#endif
-	case 'D':		/* connect to server */
-	    set_chasen_server(Cha_optarg);
-	    break;
 	case 'r':		/* chasenrc file */
 	    cha_set_rcpath(Cha_optarg);
 	    break;
 	case 'R':		/* don't read chasenrc file */
 	    cha_set_rcpath("*");
 	    break;
-	case 'P':		/* port no */
-	    set_chasen_port(Cha_optarg);
-	    break;
 	case 'o':
 	    output_file = Cha_optarg;
 	    break;
@@ -357,34 +288,16 @@ chasen_standalone(char **argv, FILE * output)
 int
 main(int argc, char *argv[])
 {
-    char *serv_env;
+    int rc;
+    FILE *output;
 
     cha_set_progpath(argv[0]);
 
-    /*
-     * Ķѿ CHASENSERVER 
-     */
-    if ((serv_env = getenv("CHASENSERVER")) != NULL)
-	set_chasen_server(serv_env);
-
     getopt_argv(argv);
 
-    if (Cha_server_mode) {
-#ifndef NO_SERVER
-	return chasen_server(argv, chasen_port);
-#endif
-    } else {
-	int rc;
-	FILE *output;
-	output = output_file ? cha_fopen(output_file, "w", 1) : stdout;
-#ifndef NO_SERVER
-	if (chasen_host[0])
-	    rc = chasen_client(argv, output, chasen_host, chasen_port);
-	else
-#endif
-	    rc = chasen_standalone(argv, output);
-	if (output != stdout)
-	    fclose(output);
-	return rc;
-    }
+    output = output_file ? cha_fopen(output_file, "w", 1) : stdout;
+    rc = chasen_standalone(argv, output);
+    if (output != stdout)
+	fclose(output);
+    return rc;
 }
