@@ -2,7 +2,7 @@
  * chadic.h
  *     1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
  *
- * $Id: chadic.h,v 1.18.4.1 2002/02/05 13:42:07 akira-k Exp $
+ * $Id: chadic.h,v 1.35 2003/01/08 12:12:24 kazuma-t Exp $
  */
 
 #ifndef __CHADIC_H__
@@ -20,9 +20,6 @@
 #include <sys/types.h>
 #endif /* HAVE_UNISTD_H */
 
-#include "pat.h"
-#include "sufary.h"
-
 #ifndef FALSE
 #define FALSE  ((int)0)
 #endif
@@ -53,7 +50,6 @@
 #define ESTR_BOS             "BOS"
 #define JSTR_EOS             "ʸ"
 #define ESTR_EOS             "EOS"
-#define JSTR_BKUGIRI         "/"
 #define ESTR_BOS_EOS         "BOS/EOS"
 
 /* cforms.cha */
@@ -122,6 +118,7 @@
 #define ESTR_OUTPUT_COMPOUND   "OUTPUT_COMPOUND"
 #define ESTR_PAT_FILE       "PATDIC" /* changed by Tatuo 960920 */
 #define ESTR_SUF_FILE       "SUFDIC"
+#define ESTR_DA_FILE       "DADIC"
 #define JSTR_OUTPUT_FORMAT  "ϥեޥå"
 #define ESTR_OUTPUT_FORMAT  "OUTPUT_FORMAT"
 #define JSTR_LANG           ""
@@ -225,7 +222,6 @@ typedef struct _hinsi_t {
     short *path;         /* the path to top node */
     short *daughter;     /* the daughter node */
     char  *name;         /* the name of POS (at the level) */
-    char  *bkugiri;      /* for bunsetsu segmentation */
     short composit;      /* for the COMPOSIT_POS */ 
     char  depth;         /* the depth from top node */
     char  kt;            /* have conjugation or not */
@@ -273,16 +269,9 @@ extern int Cha_lineno, Cha_lineno_error;
 extern int Cha_optind;
 extern char *Cha_optarg;
 
-extern int Cha_server_mode;
 extern int Cha_errno;
 extern FILE *Cha_stderr;
 
-/* dictionaries(dic.c) */
-extern SUFARY *Suf_dicfile[];
-extern pat_t *Pat_dicfile[];
-extern int Suf_ndicfile;
-extern int Pat_ndicfile;
-
 /*
  * functions
  */
@@ -311,8 +300,6 @@ FILE *cha_fopen_rcfile(void);
 void cha_read_grammar_dir(void);
 
 /* lisp.c */
-void cha_set_getc_alone(void);
-void cha_set_getc_server(void);
 void cha_set_skip_char(int);
 int cha_s_feof(FILE*);
 void cha_s_free(chasen_cell_t*);
@@ -361,11 +348,6 @@ unsigned char *hankana2zenkana(unsigned char*);
 int cha_getopt(char**, char*, FILE*);
 int cha_getopt_chasen(char**, FILE*);
 
-/* mmap.c */
-off_t cha_mmap_file(char*, void**);
-off_t cha_mmap_file_w(char*, void**);
-void cha_munmap_file(void*, off_t);
-
 #endif /* __CHADIC_H__ */
 
 
