@@ -1,5 +1,5 @@
 /*
- * $Id: chalib.h,v 1.16 2001/03/15 21:25:48 masayu-a Exp $
+ * $Id: chalib.h,v 1.38 2003/02/14 07:41:34 kazuma-t Exp $
  */
 
 #ifndef __CHALIB_H__
@@ -16,7 +16,9 @@
 #define CHA_PATH_NUM            1024
 #define CHA_INPUT_SIZE      8192
 #define UNDEF_HINSI_MAX     256
-#define PAT_DIC_NUM 5 /* Ʊ˻Ȥ뼭οξ (ChaSen) */
+#define PAT_DIC_NUM 32 /* Ʊ˻Ȥ뼭οξ (ChaSen) */
+
+#define MRPH_NUM            1024
 
 /*
  * structures
@@ -66,10 +68,13 @@ typedef struct _undef_info {
     int  hinsi;
 } undef_info;
 
+typedef struct _cha_mmap_t cha_mmap_t;
+typedef struct _cha_block_t cha_block_t;
+
 /*
  * global variables
  */
-extern mrph2_t *Cha_mrph;
+extern cha_block_t *Cha_mrph_block;
 extern path_t *Cha_path;
 extern int Cha_path_num;
 extern int Cha_con_cost_weight, Cha_con_cost_undef;
@@ -82,6 +87,17 @@ extern char *Cha_bos_string;
 extern char *Cha_eos_string;
 extern int Cha_output_iscompound;
 
+/* dictionaries(dic.c) */
+#include "pat.h"
+#include "sufary.h"
+#include "dartsdic.h"
+extern SUFARY *Suf_dicfile[];
+extern pat_t *Pat_dicfile[];
+extern darts_t *Da_dicfile[];
+extern int Suf_ndicfile;
+extern int Pat_ndicfile;
+extern int Da_ndicfile;
+
 /*
  * functions
  */
@@ -92,7 +108,6 @@ void cha_init(void);
 
 /* print.c */
 char *cha_get_output(void);
-void cha_set_fput(int);
 void cha_set_output(FILE*);
 void cha_print_reset(void);
 void cha_printf_mrph(int, mrph2_t*, char*);
@@ -104,7 +119,7 @@ void cha_print_cform_table(void);
 
 /* parse.c */
 void cha_get_mrph_data(mrph2_t*, char*, char*);
-int cha_parse_sentence(char*, int, int);
+int cha_parse_sentence(char*, int);
 
 /* chalib.c */
 void cha_version(FILE*);
@@ -114,6 +129,7 @@ void cha_set_language(char*);
 char *cha_fgets(char*, int, FILE*);
 void cha_read_patdic(chasen_cell_t*);
 void cha_read_sufdic(chasen_cell_t*);
+void cha_read_dadic(chasen_cell_t*);
 
 /* cha_jfgets.c */
 void cha_set_jfgets_delimiter(char*);
@@ -121,4 +137,20 @@ char *cha_fget_line(char*, int, FILE*);
 char *cha_jfgets(char*, int, FILE*);
 int cha_jistoeuc(unsigned char*, unsigned char*);
 
+/* mmap.c */
+cha_mmap_t *cha_mmap_file(char*);
+cha_mmap_t *cha_mmap_file_w(char*);
+void cha_munmap_file(cha_mmap_t*);
+void *cha_mmap_map(cha_mmap_t*);
+off_t cha_mmap_size(cha_mmap_t*);
+
+/* block.c */
+cha_block_t *cha_block_new(size_t, int);
+void cha_block_delete(cha_block_t*);
+void *cha_block_new_item(cha_block_t*);
+void *cha_block_get_item(cha_block_t*, int);
+void *cha_block_pop(cha_block_t*);
+int cha_block_num(cha_block_t*);
+void cha_block_clear(cha_block_t*);
+
 #endif /* __CHALIB_H__ */
