@@ -35,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
  * Author: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr 1997
- * $Id: getopt.c,v 1.4 2001/02/24 06:17:22 kazuma-t Exp $
+ * $Id: getopt.c,v 1.8 2003/01/08 12:12:24 kazuma-t Exp $
  */
 
 #include <stdio.h>
@@ -121,7 +121,7 @@ cha_getopt(char **argv, char *optstring, FILE * fp)
 int
 cha_getopt_chasen(char **argv, FILE * fp)
 {
-    return cha_getopt(argv, "sP:D:RabmpdvfecMo:F:L:l:jr:w:O:BChV", fp);
+    return cha_getopt(argv, "sP:D:RabmpdvfecMo:F:L:l:jr:w:O:ChV", fp);
 }
 
 
