@@ -35,11 +35,12 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
  * Modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp> Sep. 1996
- * $Id: init.c,v 1.12.4.1 2002/01/05 07:05:33 kazuma-t Exp $
+ * $Id: init.c,v 1.29 2003/02/14 07:41:34 kazuma-t Exp $
  */
 
 #include "chalib.h"
 #include "pat.h"
+#include "dartsdic.h"
 #include "tokenizer.h"
 
 /*
@@ -51,8 +52,6 @@
 #define COST_WIDTH_DEFAULT	0
 #define UNDEF_WORD_DEFAULT	10000
 
-int Cha_server_mode;
-
 int Cha_con_cost_weight = RENSETSU_WEIGHT_DEFAULT * MRPH_DEFAULT_WEIGHT;
 int Cha_con_cost_undef = 0;
 int Cha_mrph_cost_weight = KEITAISO_WEIGHT_DEFAULT;
@@ -69,6 +68,7 @@ chasen_tok_t *Cha_tokenizer;
 
 extern int Suf_ndicfile;
 extern int Pat_ndicfile;
+extern int Da_ndicfile;
 
 static void
 read_class_cost(chasen_cell_t * cell)
@@ -169,6 +169,8 @@ eval_chasenrc_sexp(chasen_cell_t * cell)
 	cha_read_patdic(cha_cdr(cell));
     else if (!strcmp(cell1_str, ESTR_SUF_FILE))
 	cha_read_sufdic(cha_cdr(cell));
+    else if (!strcmp(cell1_str, ESTR_DA_FILE))
+	cha_read_dadic(cha_cdr(cell));
     /*
      * ʻ(space pos) 
      */
@@ -328,8 +330,8 @@ read_chasenrc(void)
 	cha_exit(1, "%s: UNKNOWN_POS/michigo-hinsi is not specified",
 		 cha_get_rcpath());
 
-    if (!Pat_ndicfile && !Suf_ndicfile)
-	cha_exit(1, "%s: patricia dictionary is not specified",
+    if (!Pat_ndicfile && !Suf_ndicfile && !Da_ndicfile)
+	cha_exit(1, "%s: dictionary is not specified",
 		 cha_get_rcpath());
 }
 
@@ -341,16 +343,6 @@ cha_init(void)
 {
     int i;
 
-    /*
-     * ϴؿؤΥݥ 
-     */
-    cha_set_fput(Cha_server_mode);
-
-    /*
-     * ϴؿؤΥݥ 
-     */
-    cha_set_getc_alone();
-
     /*
      * cost width 
      */
@@ -374,4 +366,6 @@ cha_init(void)
      */
     Cha_tokenizer = cha_tok_new(Cha_lang, Cha_encode);
     cha_tok_set_annotation(Cha_tokenizer, Cha_anno_info);
+
+    Cha_mrph_block = cha_block_new(sizeof(mrph2_t), MRPH_NUM);
 }
