@@ -35,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  *
  * 1990/12/17/Mon       Yutaka MYOKI(Nagao Lab., KUEE)
- * $Id: katuyou.c,v 1.8.4.1 2002/02/05 13:42:07 akira-k Exp $
+ * $Id: katuyou.c,v 1.12 2003/02/13 16:15:59 kazuma-t Exp $
  */
 
 #include "chadic.h"
@@ -90,9 +90,6 @@ read_type_form(FILE * fp)
 	    else {
 		Cha_form[i][j].gobi = cha_strdup(s);
 		Cha_form[i][j].gobi_len = strlen(s);
-#ifdef SJIS
-		sjis2euc(Cha_form[i][j].gobi);
-#endif
 	    }
 	    /*
 	     * ygobi 
@@ -103,9 +100,6 @@ read_type_form(FILE * fp)
 		Cha_form[i][j].ygobi = "";
 	    else {
 		Cha_form[i][j].ygobi = cha_strdup(s);
-#ifdef SJIS
-		sjis2euc(Cha_form[i][j].ygobi);
-#endif
 	    }
 	    /*
 	     * pgobi 
@@ -116,9 +110,6 @@ read_type_form(FILE * fp)
 		Cha_form[i][j].pgobi = "";
 	    else {
 		Cha_form[i][j].pgobi = cha_strdup(s);
-#ifdef SJIS
-		sjis2euc(Cha_form[i][j].pgobi);
-#endif
 	    }
 	}
 	if (!Cha_type[i].basic)
