@@ -36,35 +36,27 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Modified by: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Oct. 1996
- * $Id: parse.c,v 1.24.4.7 2001/07/08 09:05:28 masayu-a Exp $
+ * $Id: parse.c,v 1.46 2003/02/14 07:41:34 kazuma-t Exp $
  */
 
 #include "chalib.h"
 #include "pat.h"
 #include "sufary.h"
 #include "tokenizer.h"
+#include "dartsdic.h"
 
-#define MRPH_NUM	        1024
 #define PATH1_NUM		256
 
-#define HANKAKU            	0x80
-#define PRIOD            	0xa1a5
-#define CHOON            	0xa1bc
-#define KIGOU            	0xa3b0
-#define SUJI           	        0xa3c0
-#define ALPH            	0xa4a0
-#define HIRAGANA                0xa5a0
-#define KATAKANA                0xa6a0
-#define GR                      0xb0a0
-#define KANJI                   0xffff
-#define ILLEGAL                 1
-
 #define is_spc(c)    ((c)==' '||(c)=='\t')
 
-mrph2_t *Cha_mrph = NULL;
+cha_block_t *Cha_mrph_block;
 path_t *Cha_path = NULL;
 int Cha_path_num;
 
+#define new_mrph() cha_block_new_item(Cha_mrph_block)
+#define nth_mrph(n) ((mrph2_t*)cha_block_get_item(Cha_mrph_block,(n)))
+#define mrph_last_idx() (cha_block_num(Cha_mrph_block)-1)
+#define pop_mrph() cha_block_pop(Cha_mrph_block)
 
 /*
  * malloc_chars
@@ -77,7 +69,7 @@ int Cha_path_num;
 static void *
 malloc_chars(int size, int nitems)
 {
-    static char *buffer_ptr[128];
+    static char *buffer_ptr[256];
     static int buffer_ptr_num = 0;
     static int buffer_idx = CHA_MALLOC_SIZE;
 
@@ -101,7 +93,7 @@ malloc_chars(int size, int nitems)
 	}
 
 	if (buffer_idx + nitems >= CHA_MALLOC_SIZE) {
-	    if (buffer_ptr_num == 128)
+	    if (buffer_ptr_num == 256)
 		cha_exit(1, "Can't allocate memory");
 	    buffer_ptr[buffer_ptr_num++] = cha_malloc(CHA_MALLOC_SIZE);
 	    buffer_idx = 0;
@@ -152,26 +144,13 @@ malloc_free_path(int do_free)
     return Cha_path == NULL;
 }
 
-#define malloc_mrph()  malloc_free_mrph(0)
-#define free_mrph()    malloc_free_mrph(1)
-static int
-malloc_free_mrph(int do_free)
-{
-    static int nblock = 0;
-
-    Cha_mrph = malloc_free_block((void *) Cha_mrph, &nblock,
-				 sizeof(mrph2_t) * MRPH_NUM, do_free);
-
-    return Cha_mrph == NULL;
-}
-
 /*
  * register_undef_mrph1 - ̤Хåեɲ
  */
 static int
-register_undef_mrph1(char *target, int mrph_idx, int undef_len, int no)
+register_undef_mrph1(char *target, int undef_len, int no)
 {
-    mrph2_t *mrph = &Cha_mrph[mrph_idx];
+    mrph2_t *mrph = new_mrph();
 
     mrph->midasi = target;
     mrph->yomi = "";
@@ -188,31 +167,19 @@ register_undef_mrph1(char *target, int mrph_idx, int undef_len, int no)
     mrph->weight = MRPH_DEFAULT_WEIGHT;
     mrph->info = "";		/* ղþ϶ʸȤ롥 */
 
-    if (++mrph_idx % MRPH_NUM == 0 && malloc_mrph())
-	return FALSE;
-
-    return TRUE;
+    return mrph_last_idx();
 }
 
 /*
  * register_mrph - ѤĴ٤ʤǤХåեɲ
- *
- * Retern value:
- * If successful, this rutine returns the number of morphs
- * added to the buffer. If an error occurs, return -1.
  */
 static int
-register_mrph(int mrph_idx)
+register_mrph(mrph2_t *new_mrph)
 {
-    int new_mrph_idx = mrph_idx;
-    mrph2_t *new_mrph = &Cha_mrph[mrph_idx];
-
     if (!new_mrph->ktype) {
 	/*
 	 * Ѥʤ 
 	 */
-	if (++new_mrph_idx % MRPH_NUM == 0 && malloc_mrph())
-	    return -1;
     } else {
 	/*
 	 * Ѥ 
@@ -224,8 +191,6 @@ register_mrph(int mrph_idx)
 	    new_mrph->base_length = 0;
 	    new_mrph->yomi = "";
 	    new_mrph->pron = "";
-	    if (++new_mrph_idx % MRPH_NUM == 0 && malloc_mrph())
-		return -1;
 	} else {
 	    /*
 	     * 촴 
@@ -235,52 +200,87 @@ register_mrph(int mrph_idx)
 	    int baselen = new_mrph->length;
 	    int con_tbl = new_mrph->con_tbl;
 	    char *follows = new_mrph->midasi + baselen;
-	    int new_mrph_idx0 = new_mrph_idx;
+	    mrph2_t *new_mrph0 = new_mrph;
+	    new_mrph->kform = 0;
 	    for (f = 1; Cha_form[ktype][f].name; f++) {
 		if (!Cha_form[ktype][f].gobi[0] ||
 		    (follows[0] == Cha_form[ktype][f].gobi[0] &&
 		     !memcmp(follows, Cha_form[ktype][f].gobi,
 			     Cha_form[ktype][f].gobi_len))) {
-		    if (new_mrph_idx != new_mrph_idx0)
-			*new_mrph = Cha_mrph[new_mrph_idx0];
+		    if (new_mrph->kform > 0) {
+			new_mrph = new_mrph();
+			*new_mrph = *new_mrph0;
+		    }
 		    new_mrph->kform = f;
 		    new_mrph->length =
 			baselen + Cha_form[ktype][f].gobi_len;
 		    new_mrph->con_tbl = con_tbl + f - 1;
-		    if (++new_mrph_idx % MRPH_NUM == 0 && malloc_mrph())
-			return -1;
-		    new_mrph = &Cha_mrph[new_mrph_idx];
 		}
 	    }
+	    if (new_mrph->kform == 0)
+		pop_mrph();
 	}
     }
 
-    return new_mrph_idx - mrph_idx;
+    return mrph_last_idx();
 }
 
 /*
  * convert_mrphs - ǤХåեɲ
- * 
- * Retern value:
- * If successful, this rutine returns the number of morphs
- * added to the buffer. If an error occurs, return -1.
  */
 static int
-convert_mrphs(char *target, char **dic_buffer, int mrph_idx)
+convert_mrphs(char *target, char **dic_buffer)
 {
-    int nmrph;
-    int new_mrph_idx = mrph_idx;
+    mrph2_t *new_mrph;
     char **pbuf;
 
     for (pbuf = dic_buffer; *pbuf; pbuf++) {
-	cha_get_mrph_data(&Cha_mrph[new_mrph_idx], *pbuf, target);
-	nmrph = register_mrph(new_mrph_idx);
-	if (nmrph < 0)
-	    return -1;
-	new_mrph_idx += nmrph;
+	new_mrph = new_mrph();
+	cha_get_mrph_data(new_mrph, *pbuf, target);
+	register_mrph(new_mrph);
     }
 
-    return new_mrph_idx - mrph_idx;
+    return mrph_last_idx();
+}
+
+static void
+da_get_mrph_data(darts_t* da, mrph2_t *mrph, da_lex_t *lex_data,
+		 char *str, int str_len)
+{
+    mrph->midasi = str;
+    mrph->base_length = mrph-> length = str_len;
+    mrph->is_undef = 0;
+
+    mrph->hinsi = lex_data->posid;
+    mrph->ktype = lex_data->inf_type;
+    mrph->kform = lex_data->inf_form;
+    mrph->weight = lex_data->weight;
+    mrph->con_tbl = lex_data->con_tbl;
+
+    da_get_data(da, lex_data->dat_index,
+		&(mrph->yomi), &(mrph->pron), &(mrph->base), &(mrph->info),
+		&(mrph->compound));
+}
+
+static int
+da_convert_mrphs(darts_t* da, char *target, long *indecies)
+{
+    mrph2_t *new_mrph;
+    long *index;
+    da_lex_t lex_data[256]; /* XXX */
+
+    for (index = indecies; *index >= 0; index++) {
+	int nlex, i, target_len;
+	nlex = da_get_lex(da, *index, lex_data, &target_len);
+	for (i = 0; i < nlex; i++) {
+	    new_mrph = new_mrph();
+	    da_get_mrph_data(da, new_mrph,
+			     lex_data + i, target, target_len);
+	    register_mrph(new_mrph);
+	}
+    }
+
+    return mrph_last_idx();
 }
 
 /*
@@ -347,7 +347,7 @@ check_connect(int pos, int m_num, int *p_idx)
 #ifdef DEBUG
     printf("[m:%d] ", m_num);
 #endif
-    new_mrph = &Cha_mrph[m_num];
+    new_mrph = nth_mrph(m_num);
     con_tbl = new_mrph->con_tbl;
 
     pcost[0].state = -1;
@@ -473,7 +473,7 @@ check_connect(int pos, int m_num, int *p_idx)
 }
 
 static void
-set_mrph_end(mrph2_t * mrph)
+set_mrph_end(mrph2_t *mrph)
 {
     mrph->midasi = mrph->yomi = mrph->info = "";
     mrph->base = mrph->pron = "";
@@ -489,46 +489,18 @@ set_mrph_end(mrph2_t * mrph)
 }
 
 static int
-set_mrph_bkugiri(void)
-{
-    static int bkugiri_num;
-    int h;
-    mrph2_t *mrph;
-
-    if (Cha_mrph[1].midasi)
-	return bkugiri_num;
-
-    for (h = 0; Cha_hinsi[h].name; h++) {
-	if (!Cha_hinsi[h].bkugiri)
-	    continue;
-	mrph = &Cha_mrph[++bkugiri_num];
-	/*
-	 * memset: unnecessary? 
-	 */
-	memset(mrph, 0, sizeof(mrph2_t));
-
-	mrph->hinsi = h;
-	mrph->con_tbl = cha_check_table_for_undef(h);
-	mrph->midasi = mrph->yomi = mrph->base = mrph->pron =
-	    Cha_hinsi[h].bkugiri;
-	mrph->info = "";
-    }
-    return bkugiri_num;
-}
-
-static int
-lookup_dic(char *target, int target_len, int cursor, int new_mrph_idx)
+lookup_dic(char *target, int target_len, int cursor)
 {
     int dic_no;
     char *dic_buffer[256];
+    long index_buffer[256]; /* for Darts */
 
     /*
      * (ʸΤ߸) EUC only 
      */
-    if (Cha_encode == CHASEN_ENCODE_EUCJP &&
+    if ((Cha_encode == CHASEN_ENCODE_EUCJP || Cha_encode == CHASEN_ENCODE_SJIS) &&
 	cha_tok_mblen_on_cursor(Cha_tokenizer, cursor) == 2) {
 	for (dic_no = 0; dic_no < Pat_ndicfile; dic_no++) {
-	    int nmrph;
 	    /*
 	     * ѥȥꥷڤǤ򸡺 
 	     */
@@ -536,16 +508,11 @@ lookup_dic(char *target, int target_len, int cursor, int new_mrph_idx)
 	    /*
 	     * ѤĤķǤ Cha_mrph ɲ 
 	     */
-	    nmrph = convert_mrphs(target + cursor, dic_buffer,
-				  new_mrph_idx);
-	    if (nmrph < 0)
-		return -1;
-	    new_mrph_idx += nmrph;
+	    convert_mrphs(target + cursor, dic_buffer);
 	}
     }
 
     for (dic_no = 0; dic_no < Suf_ndicfile; dic_no++) {
-	int nmrph;
 	/*
 	 * SUFARY ե뤫Ǥ򸡺 
 	 */
@@ -555,13 +522,16 @@ lookup_dic(char *target, int target_len, int cursor, int new_mrph_idx)
 	/*
 	 * ѤĤķǤ Cha_mrph ɲ 
 	 */
-	nmrph = convert_mrphs(target + cursor, dic_buffer, new_mrph_idx);
-	if (nmrph < 0)
-	    return -1;
-	new_mrph_idx += nmrph;
+	convert_mrphs(target + cursor, dic_buffer);
     }
 
-    return new_mrph_idx;
+    for (dic_no = 0; dic_no < Da_ndicfile; dic_no++) {
+	da_lookup(Da_dicfile[dic_no],
+		  target + cursor, target_len - cursor, index_buffer);
+	da_convert_mrphs(Da_dicfile[dic_no], target + cursor, index_buffer);
+    }
+
+    return mrph_last_idx();
 }
 
 
@@ -569,24 +539,21 @@ lookup_dic(char *target, int target_len, int cursor, int new_mrph_idx)
  * ̤ 
  */
 static int
-set_undefword(char *target, int cursor, int new_mrph_idx, int mrph_idx,
-	      int *path_idx)
+set_undefword(char *target, int cursor, int head_mrph_idx, int tail_mrph_idx)
 {
     int undef_len;
     int i;
 
     undef_len = cha_tok_char_type_len(Cha_tokenizer, cursor);
-    /*
-     * ľΥѥȤ³å 
-     */
-    for (i = mrph_idx; i < new_mrph_idx; i++) {
+
+    for (i = head_mrph_idx; i <= tail_mrph_idx; i++) {
 	/*
 	 * ̤ƱĹñ줬ˤ̤ɲäʤ 
 	 */
-	if (Cha_con_cost_undef > 0 && Cha_mrph[i].length == undef_len)
+	if (Cha_con_cost_undef > 0 && nth_mrph(i)->length == undef_len) {
 	    undef_len = 0;
-	if (check_connect(cursor, i, path_idx) == FALSE)
-	    return -1;
+	    break;
+	}
     }
 
     /*
@@ -594,48 +561,11 @@ set_undefword(char *target, int cursor, int new_mrph_idx, int mrph_idx,
      */
     if (undef_len > 0) {
 	int no;
-	for (no = 0; no < Cha_undef_info_num; no++, new_mrph_idx++) {
-	    if (register_undef_mrph1(target + cursor, new_mrph_idx,
-				     undef_len, no) == FALSE)
-		return -1;
-	    if (check_connect(cursor, new_mrph_idx, path_idx) == FALSE)
-		return -1;
-#if 0
-	    printf("path[0]: %d:%d\n", Cha_path_num - 1,
-		   Cha_path[Cha_path_num - 1].path[0]);
-#endif
-	}
+	for (no = 0; no < Cha_undef_info_num; no++)
+	    register_undef_mrph1(target + cursor, undef_len, no);
     }
 
-    return new_mrph_idx;
-}
-
-static int
-add_bkugiri(int cursor, int *path_idx, int path_idx_num, int bkugiri_num)
-{
-    int bk;
-
-    for (bk = 0; bk < bkugiri_num; bk++) {
-	int path_num;
-	path_num = Cha_path_num;
-	/*
-	 * ʸڤɲ 
-	 */
-	if (check_connect(cursor, bk + 1, path_idx) == FALSE)
-	    return -1;
-#if 0
-	printf("PATH: %d: %d -> %d\n", cursor, path_num, Cha_path_num);
-#endif
-	/*
-	 * ɲä줿 path  path_idx ɲ 
-	 */
-	if (Cha_path_num > path_num)
-	    for (; path_num < Cha_path_num; path_num++)
-		path_idx[path_idx_num++] = path_num;
-	path_idx[path_idx_num] = -1;
-    }
-
-    return path_idx_num;
+    return mrph_last_idx();
 }
 
 #define cursor_sep(c, l) \
@@ -651,19 +581,17 @@ add_bkugiri(int cursor, int *path_idx, int path_idx_num, int bkugiri_num)
  *     1 - no result / too many morphs
  */
 int
-cha_parse_sentence(char *target, int target_len, int opt_nobk)
+cha_parse_sentence(char *target, int target_len)
 {
     int cursor, prev_cursor;
     int path_idx[PATH1_NUM], path_idx_num;
-    int mrph_idx, new_mrph_idx;
-    int bkugiri_num = 0;
     static int path0 = -1;
 
     cha_tok_parse(Cha_tokenizer, target, target_len + 1);
+    cha_block_clear(Cha_mrph_block);
 
     free_chars();
     free_path();
-    free_mrph();
 
     /*
      * ʸƬ
@@ -675,10 +603,7 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
     Cha_path[0].state = 0;
 
     Cha_path_num = 1;
-    set_mrph_end(&Cha_mrph[0]);
-    if (!opt_nobk)
-	bkugiri_num = set_mrph_bkugiri();
-    new_mrph_idx = mrph_idx = bkugiri_num + 1;
+    set_mrph_end(new_mrph());
 
     /*
      * ܽ
@@ -686,6 +611,9 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
     for (cursor = prev_cursor = 0; cursor < target_len;
 	cursor += cursor_sep(cursor, target_len - cursor),
 	prev_cursor = cursor) {
+	int mrph_idx;
+	int i;
+
         /* skip annotations and white space */
 	while (cha_tok_anno_type(Cha_tokenizer, cursor) != 0 )
 	  cursor += cha_tok_char_type_len(Cha_tokenizer, cursor);
@@ -693,44 +621,33 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
 	  break;
 	
 	path_idx_num = collect_mrphs_for_pos(prev_cursor, path_idx);
-
 	if (path_idx_num == 0)
 	    continue;
-
-	/* add BUNSETSU (the POS with length 0) information */
-	path_idx_num = add_bkugiri(cursor,
-				   path_idx, path_idx_num, bkugiri_num);
-	if (path_idx_num < 0)
+	else if (path_idx_num < 0)
 	    goto error_end;
 
+	mrph_idx = mrph_last_idx() + 1;
 	/* pick up possible words from dictionary */
-	new_mrph_idx = lookup_dic(target, target_len, cursor, new_mrph_idx);
-	if (new_mrph_idx < 0)
-	    goto error_end;
+	lookup_dic(target, target_len, cursor);
 
 	/* set undefined word */
-	/* check the path between the preceding and current position  */
-	new_mrph_idx = set_undefword(target, cursor,
-				     new_mrph_idx, mrph_idx, path_idx);
-	if (new_mrph_idx < 0)
-	    goto error_end;
+	set_undefword(target, cursor, mrph_idx, mrph_last_idx());
 
-	mrph_idx = new_mrph_idx;
+	/* check the path between the preceding and current position  */
+	for (i = mrph_idx; i <= mrph_last_idx(); i++) {
+	    if (check_connect(cursor, i, path_idx) == FALSE)
+		goto error_end;
+	}
     }
 
     /*
      * ʸ
      */
-    set_mrph_end(&Cha_mrph[mrph_idx++]);
-    if (mrph_idx % MRPH_NUM == 0 && malloc_mrph())
-        goto error_end;
-    
+    set_mrph_end(new_mrph());
     path_idx_num = collect_mrphs_for_pos(prev_cursor, path_idx);
-
-    if (check_connect(cursor, mrph_idx - 1, path_idx) == FALSE)
+    if (check_connect(cursor, mrph_last_idx(), path_idx) == FALSE)
         goto error_end;
 
- 
     return 0;
 
     /*
