@@ -37,7 +37,7 @@
  *
  *  modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
  *           by O.Imaichi <osamu-im@is.aist-nara.ac.jp>, Sep. 1996
- * $Id: print.c,v 1.17.2.1 2001/03/16 23:44:18 masayu-a Exp $
+ * $Id: print.c,v 1.35 2003/02/14 07:41:34 kazuma-t Exp $
  */
 
 #include <stdarg.h>
@@ -47,14 +47,14 @@
 #include "tokenizer.h"
 #include "pat.h"
 
+#define nth_mrph(n) ((mrph2_t*)cha_block_get_item(Cha_mrph_block,(n)))
+
 #define CHA_OUTPUT_SIZE (1024*16)
 
 static int path_buffer[CHA_INPUT_SIZE];
-static int is_bol = 1;
 static int pos_end = 0;
 
 static void (*cha_putc) (), (*cha_puts) (), (*cha_printf) ();
-static void (*cha_fputc) (), (*cha_fputs) (), (*cha_fprintf) ();
 
 void
 cha_print_reset(void)
@@ -62,50 +62,6 @@ cha_print_reset(void)
     pos_end = 0;
 }
 
-/*
- * cha_clputc, cha_clputs, cha_clprintf
- *      - output functions for ChaSen client
- */
-static void
-cha_clputc(int c, FILE * output)
-{
-    if (is_bol && c == '.')
-	putc('.', output);
-
-    putc(c, output);
-
-    is_bol = c == '\n' ? 1 : 0;
-}
-
-static void
-cha_clputs(char *s, FILE * output)
-{
-    if (is_bol && s[0] == '.')
-	putc('.', output);
-
-    fputs(s, output);
-
-    is_bol = s[strlen(s) - 1] == '\n' ? 1 : 0;
-}
-
-static void
-cha_clprintf(FILE * output, char *format, ...)
-{
-    char tmpbuf[CHA_INPUT_SIZE];
-    va_list ap;
-
-    va_start(ap, format);
-    vsprintf(tmpbuf, format, ap);
-    va_end(ap);
-
-    if (is_bol && tmpbuf[0] == '.')
-	putc('.', output);
-
-    fputs(tmpbuf, output);
-
-    is_bol = tmpbuf[strlen(tmpbuf) - 1] == '\n' ? 1 : 0;
-}
-
 /*
  * cha_sputc, cha_sputs, cha_sprintf
  *      - output fuctions to string
@@ -163,9 +119,11 @@ cha_sprintf(char *output, char *format, ...)
 }
 
 void
-cha_set_fput(int server_mode)
+cha_set_output(FILE * output)
 {
     /*
+     * XXX
+     *
      * For system having no prototype declarations for the following
      * functions such as SunOS 4.1.4. 
      */
@@ -173,20 +131,6 @@ cha_set_fput(int server_mode)
     extern int fputs(const char *, FILE *);
     extern int fprintf(FILE *, const char *, ...);
 
-    if (server_mode) {
-	cha_fputc = (void (*)) cha_clputc;
-	cha_fputs = (void (*)) cha_clputs;
-	cha_fprintf = (void (*)) cha_clprintf;
-    } else {
-	cha_fputc = (void (*)) fputc;
-	cha_fputs = (void (*)) fputs;
-	cha_fprintf = (void (*)) fprintf;
-    }
-}
-
-void
-cha_set_output(FILE * output)
-{
     if (output == NULL) {
 	/*
 	 * output to string 
@@ -210,9 +154,9 @@ cha_set_output(FILE * output)
 	 * output to file 
 	 */
 	cha_output = (char *) output;
-	cha_putc = (void (*)) cha_fputc;
-	cha_puts = (void (*)) cha_fputs;
-	cha_printf = (void (*)) cha_fprintf;
+	cha_putc = (void (*)) fputc;
+	cha_puts = (void (*)) fputs;
+	cha_printf = (void (*)) fprintf;
     }
 }
 
@@ -506,8 +450,8 @@ printf_field(char *width_str, char *word)
 	field_putsn(word, cha_output, word_len);
     }
 }
-#undef strtoi(s, i)
-#undef field_putsn((w), (o), (l))
+#undef strtoi
+#undef field_putsn
 
 static int
 get_deli_right(int c)
@@ -580,6 +524,12 @@ print_anno(int path_num, char *format)
     path->start = start;
 }
 
+/* XXX: this code is valid only with EUC-JP and Shift-JIS */
+#define copy_mbstr(d,s) \
+do { *(d)++ = *(s); \
+    if ((unsigned char)(*(s)) & 0x80 && *++(s)) *(d)++ = *(s); \
+} while (0)
+
 static void
 extract_yomi1(char *dst, char *src)
 {
@@ -597,14 +547,14 @@ extract_yomi1(char *dst, char *src)
 	    if (*s == '{')
 		in_brace = is1st = 1;
 	    else
-		*d++ = *s;
+		copy_mbstr(d, s);
 	} else if (*s == '}')
 	    in_brace = 0;
 	else if (is1st) {
 	    if (*s == '/')
 		is1st = 0;
 	    else
-		*d++ = *s;
+		copy_mbstr(d, s);
 	}
     }
 
@@ -705,17 +655,11 @@ cha_printf_mrph(int path_num, mrph2_t * mrph, char *format)
 	    }
 	    break;
 	case 'm':		/* Surface string (surface form) */
-  	    if (mrph->length == 0)    /* bunsetsu */
-		word = mrph->midasi;
-	    else {                    /* not bunsetsu */
-		memcpy(eword = word_str, mrph->midasi, mrph->length);
-		word_str[mrph->length] = '\0';
-	    }
+	    memcpy(eword = word_str, mrph->midasi, mrph->length);
+	    word_str[mrph->length] = '\0';
 	    break;
 	case 'M':		/* Surface string (base form) */
-   	    if (mrph->length == 0)  /* bunsetsu */
-		word = mrph->midasi;
-	    else if (mrph->base[0]) /* not bunsetsu */
+	    if (mrph->base[0])
 		eword = mrph->base;
 	    else {
 		memcpy(eword = word_str, mrph->midasi, mrph->base_length);
@@ -730,29 +674,25 @@ cha_printf_mrph(int path_num, mrph2_t * mrph, char *format)
 	case 'y':		/* Japanese Reading (surface form) */
 	case 'Y':		/* Japanese Reading (base form) */
 	case 'r':
-   	    if (mrph->length == 0) /* bunsetsu */
-		word = mrph->midasi;
-	    else {                 /* not bunsetsu */
-		if (mrph->yomi[0]) {
-		    if (s[0] != 'r' && s[1] != '0')
-			extract_yomi1(word_str, mrph->yomi);
-		    else
-			strcpy(word_str, mrph->yomi);
-		} else {
-		    memcpy(word_str, mrph->midasi, mrph->base_length);
-		    word_str[mrph->base_length] = '\0';
-		}
-		if (mrph->ktype > 0) {
-		    if (*s != 'Y')
-			strcat(word_str,
-			       Cha_form[mrph->ktype][mrph->kform].ygobi);
-		    else
-			strcat(word_str,
-			       Cha_form[mrph->ktype][Cha_type[mrph->ktype].
-						     basic].ygobi);
-		}
-		eword = word_str;
+	    if (mrph->ktype || mrph->yomi[0]) {
+		if (s[0] != 'r' && s[1] != '0')
+		    extract_yomi1(word_str, mrph->yomi);
+		else
+		    strcpy(word_str, mrph->yomi);
+	    } else {
+		memcpy(word_str, mrph->midasi, mrph->base_length);
+		word_str[mrph->base_length] = '\0';
 	    }
+	    if (mrph->ktype > 0) {
+		if (*s != 'Y')
+		    strcat(word_str,
+			   Cha_form[mrph->ktype][mrph->kform].ygobi);
+		else
+		    strcat(word_str,
+			   Cha_form[mrph->ktype][Cha_type[mrph->ktype].
+						 basic].ygobi);
+	    }
+	    eword = word_str;
 	    if (*s != 'r') {
 		if (s[1] == '0' || s[1] == '1')
 		    s++;
@@ -776,34 +716,30 @@ cha_printf_mrph(int path_num, mrph2_t * mrph, char *format)
 	    break;
 	case 'a':		/* Japanese pronunciation (surface form) */
 	case 'A':		/* Japanese pronunciation (base form) */
-  	    if (mrph->length == 0)   /* bunsetsu */
-		word = mrph->midasi;
-	    else {                   /* not bunsetsu */
-		if (mrph->pron[0]) {
-		    if (s[1] != '0')
-			extract_yomi1(word_str, mrph->pron);
-		    else
-			strcpy(word_str, mrph->pron);
-		} else if (mrph->yomi[0]) {
-		    if (s[1] != '0')
-			extract_yomi1(word_str, mrph->yomi);
-		    else
-			strcpy(word_str, mrph->yomi);
-		} else {
-		    memcpy(word_str, mrph->midasi, mrph->base_length);
-		    word_str[mrph->base_length] = 0;
-		}
-		if (mrph->ktype > 0) {
-		    if (*s != 'A')
-			strcat(word_str,
-			       Cha_form[mrph->ktype][mrph->kform].pgobi);
-		    else
-			strcat(word_str,
-			       Cha_form[mrph->ktype][Cha_type[mrph->ktype].
-						     basic].pgobi);
-		}
-		eword = word_str;
+	    if (mrph->ktype || mrph->pron[0]) {
+		if (s[1] != '0')
+		    extract_yomi1(word_str, mrph->pron);
+		else
+		    strcpy(word_str, mrph->pron);
+	    } else if (mrph->yomi[0]) {
+		if (s[1] != '0')
+		    extract_yomi1(word_str, mrph->yomi);
+		else
+		    strcpy(word_str, mrph->yomi);
+	    } else {
+		memcpy(word_str, mrph->midasi, mrph->base_length);
+		word_str[mrph->base_length] = 0;
 	    }
+	    if (mrph->ktype > 0) {
+		if (*s != 'A')
+		    strcat(word_str,
+			   Cha_form[mrph->ktype][mrph->kform].pgobi);
+		else
+		    strcat(word_str,
+			   Cha_form[mrph->ktype][Cha_type[mrph->ktype].
+						 basic].pgobi);
+	    }
+	    eword = word_str;
 	    if (s[1] == '0' || s[1] == '1')
 		s++;
 	    break;
@@ -955,12 +891,6 @@ cha_printf_mrph(int path_num, mrph2_t * mrph, char *format)
 	    printf_field(width_str, word);
 	    word = NULL;
 	} else if (eword != NULL) {
-#ifdef SJIS
-	    char tmp_str[CHA_INPUT_SIZE];
-	    strcpy(tmp_str, eword);
-	    euc2sjis(tmp_str);
-	    eword = tmp_str;
-#endif
 	    printf_field(width_str, eword);
 	    eword = NULL;
 	} else if (letter) {
@@ -1042,7 +972,7 @@ print_mrph(int path_num, mrph2_t * mrph, char *format)
 static void
 print_path_mrph(int path_num, char *format)
 {
-    print_mrph(path_num, &Cha_mrph[Cha_path[path_num].mrph_p], format);
+    print_mrph(path_num, nth_mrph(Cha_path[path_num].mrph_p), format);
 }
 
 static void
@@ -1165,7 +1095,7 @@ print_best_path(int opt_form, char *format)
     composit_mrph.yomi = yomi;
     composit_mrph.pron = pron;
     composit_mrph.base = base;
-    cur_mrph = &Cha_mrph[Cha_path[path_buffer[pbuf_last - 1]].mrph_p];
+    cur_mrph = nth_mrph(Cha_path[path_buffer[pbuf_last - 1]].mrph_p);
 
     /* 
      * chunking the composit POSs from EOS to BOS
@@ -1173,7 +1103,7 @@ print_best_path(int opt_form, char *format)
     for (i = pbuf_last - 1; i >= 0; i--) {   
 
 	pre_mrph = (i == 0) ?
-	    NULL : &Cha_mrph[Cha_path[path_buffer[i - 1]].mrph_p];
+	    NULL : nth_mrph(Cha_path[path_buffer[i - 1]].mrph_p);
 
 	if (i > 0 && !cur_mrph->is_undef && !pre_mrph->is_undef
 	    && (Cha_path[path_buffer[i]].end == Cha_path[path_buffer[i - 1]].start)
