@@ -35,12 +35,13 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: select.c,v 1.16 2001/03/16 04:06:17 kazuma-t Exp $
+ * $Id: select.c,v 1.21 2003/01/08 11:26:21 kazuma-t Exp $
  */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "chalib.h"
 #include "sufary.h"
 #include "tokenizer.h"
 #include "htobe.h"
@@ -54,7 +55,7 @@ static int cmp_sistr(char *, char *, int *, int);
 static eresult sa_search(SUFARY *, char *, int, int);
 
 #define sa_aryidx2txtptr(ary, idx) \
-((ary)->txtmap + betoh(((long *)((ary)->arymap + (idx) * sizeof(long)))[0]))
+(cha_mmap_map((ary)->txtmmap) + betoh(*((long *)cha_mmap_map((ary)->arymmap) + (idx))))
 
 /*
  * eresult sa_search(SUFARY *ary, char *s, int keylen, int base_offset);
@@ -100,7 +101,7 @@ sa_search(SUFARY * ary, char *s, int keylen, int base_offset)
     int prefix_length_R = base_offset;
     int offset = 0, diffpos /* ۤʤ */ ;
 
-    if (ary == NULL || ary->arymap == NULL) {
+    if (ary == NULL || ary->arymmap == NULL) {
 	fprintf(stderr, "specify target files first.\n");
 	return FAIL;
     }
