@@ -2,7 +2,7 @@
  *  SUFARY --- Suffix Array ΤΥ饤֥
  *  sufary.h - SUFARY饤֥إåե
  *
- * $Id: sufary.h,v 1.13.4.1 2002/01/05 07:05:34 kazuma-t Exp $
+ * $Id: sufary.h,v 1.19 2003/01/08 11:26:21 kazuma-t Exp $
  */
 
 #ifndef __SUFARY_H__
@@ -43,10 +43,8 @@ typedef struct {
     long arraysize; /* Array 礭 */
     long left;  /* ϰϤκü(ϰϤ¦ؤ)   g_bottom */
     long right;     /* ϰϤαü(ϰϤ¦ؤ)   g_top */
-    off_t txtsz;    /* ƥȥեΥ */
-    off_t arysz;    /* 쥤եΥ */
-    void *txtmap; /* ƥȥեΥޥåץɥ쥹 */
-    void *arymap; /* 쥤եΥޥåץɥ쥹 */
+    cha_mmap_t *txtmmap;
+    cha_mmap_t *arymmap;
 } SUFARY;
 
 /* ץȥ ѥ롼 */
