@@ -1,7 +1,7 @@
 /*
  * trans.c 1990/11/12/Mon Yutaka MYOKI(Nagao Lab., KUEE)
  *
- * $Id: trans.c,v 1.10 2001/03/15 21:25:48 masayu-a Exp $
+ * $Id: trans.c,v 1.13 2003/02/13 16:15:59 kazuma-t Exp $
  */
 
 #include "chadic.h"
@@ -163,9 +163,6 @@ get_midasi_str_weight(chasen_cell_t * cell, int def_weight, mrph_t * mrph)
 	cha_exit_file(1, "midashi `%s' is too long", midasi_str);
 
     strcpy(mrph->midasi, midasi_str);
-#ifdef SJIS
-    sjis2euc(mrph->midasi);
-#endif
 }
 
 /*
@@ -396,9 +393,6 @@ get_mrph(chasen_cell_t * block, mrph_t * mrph, int def_weight,
     if (strlen(s = cha_s_atom(cha_car(block))) > MIDASI_LEN)
 	cha_exit_file(1, "yomi `%s' is too long", s);
     strcpy(mrph->yomi, s);
-#ifdef SJIS
-    sjis2euc(mrph->yomi);
-#endif
     if (katuyou == 1)
 	trim_yomi_gobi(mrph);
     block = cha_cdr(block);
@@ -408,9 +402,6 @@ get_mrph(chasen_cell_t * block, mrph_t * mrph, int def_weight,
     if (strlen(s = cha_s_atom(cha_car(block))) > MIDASI_LEN)
 	cha_exit_file(1, "pronunciation `%s' is too long", s);
     strcpy(mrph->pron, s);
-#ifdef SJIS
-    sjis2euc(mrph->pron);
-#endif
     if (katuyou == 1)
 	trim_pron_gobi(mrph);
     block = cha_cdr(block);
@@ -424,9 +415,6 @@ get_mrph(chasen_cell_t * block, mrph_t * mrph, int def_weight,
      * ղþ 
      */
     mrph->info = cha_s_atom(cha_car(block));
-#ifdef SJIS
-    sjis2euc(mrph->info);
-#endif
     block = cha_cdr(block);
 
     return block;
@@ -507,23 +495,14 @@ get_word(chasen_cell_t * block, mrph_t * mrph, int def_weight,
     }
 
     strcpy(mrph->yomi, get_yomi(block));	/* ɤ */
-#ifdef SJIS
-    sjis2euc(mrph->yomi);
-#endif
     if (katuyou == 1)
 	trim_yomi_gobi(mrph);
 
     strcpy(mrph->pron, get_pron(block));	/* ȯ */
-#ifdef SJIS
-    sjis2euc(mrph->pron);
-#endif
     if (katuyou == 1)
 	trim_pron_gobi(mrph);
 
     mrph->info = get_info(block);	/* ղþ */
-#ifdef SJIS
-    sjis2euc(mrph->info);
-#endif
 }
 
 static void
